@@ -1,16 +1,22 @@
-from django.views import generic
-from django.db.models import get_model
-from django.core.urlresolvers import reverse_lazy
-from django.template.loader import render_to_string
 from django.contrib import messages
-from django.utils.translation import ugettext_lazy as _, ugettext
-from extra_views import (CreateWithInlinesView, UpdateWithInlinesView,
-                         InlineFormSet)
-
-from stores.dashboard import forms
-from stores.utils import get_current_ip
-from stores.dashboard.forms import OpeningHoursInline
+from django.template.loader import render_to_string
+from django.urls import reverse_lazy
+from django.utils.translation import gettext
+from django.utils.translation import gettext_lazy as _
+from django.views import generic
+from extra_views import CreateWithInlinesView, InlineFormSet, UpdateWithInlinesView
+from oscar.core.loading import get_class, get_classes, get_model
 
+MapsContextMixin = get_class('stores.views', 'MapsContextMixin')
+(DashboardStoreSearchForm,
+ OpeningHoursInline,
+ OpeningPeriodForm,
+ StoreAddressForm,
+ StoreForm) = get_classes('stores.dashboard.forms', ('DashboardStoreSearchForm',
+                                                     'OpeningHoursInline',
+                                                     'OpeningPeriodForm',
+                                                     'StoreAddressForm',
+                                                     'StoreForm'))
 Store = get_model('stores', 'Store')
 StoreGroup = get_model('stores', 'StoreGroup')
 OpeningPeriod = get_model('stores', 'OpeningPeriod')
@@ -22,7 +28,7 @@ class StoreListView(generic.ListView):
     template_name = "stores/dashboard/store_list.html"
     context_object_name = "store_list"
     paginate_by = 20
-    filterform_class = forms.DashboardStoreSearchForm
+    filterform_class = DashboardStoreSearchForm
 
     def get_title(self):
         data = getattr(self.filterform, 'cleaned_data', {})
@@ -31,16 +37,16 @@ class StoreListView(generic.ListView):
         address = data.get('address', None)
 
         if name and not address:
-            return ugettext('Stores matching "%s"') % (name)
+            return gettext('Stores matching "%s"') % (name)
         elif name and address:
-            return ugettext('Stores matching "%s" near "%s"') % (name, address)
+            return gettext('Stores matching "%s" near "%s"') % (name, address)
         elif address:
-            return ugettext('Stores near "%s"') % (address)
+            return gettext('Stores near "%s"') % (address)
         else:
-            return ugettext('Stores')
+            return gettext('Stores')
 
     def get_context_data(self, **kwargs):
-        data = super(StoreListView, self).get_context_data(**kwargs)
+        data = super().get_context_data(**kwargs)
         data['filterform'] = self.filterform
         data['queryset_description'] = self.get_title()
         return data
@@ -54,38 +60,35 @@ class StoreListView(generic.ListView):
 
 
 class StoreAddressInline(InlineFormSet):
-    extra = 1
-    max_num = 1
-    can_delete = False
+
     model = StoreAddress
-    form_class = forms.StoreAddressForm
+    form_class = StoreAddressForm
+    factory_kwargs = {
+        'extra': 1,
+        'max_num': 1,
+        'can_delete': False,
+    }
 
 
 class OpeningPeriodInline(InlineFormSet):
     extra = 7
     max_num = 7
     model = OpeningPeriod
-    form_class = forms.OpeningPeriodForm
+    form_class = OpeningPeriodForm
 
 
-class StoreEditMixin(object):
-    #inlines = [OpeningPeriodInline, StoreAddressInline]
+class StoreEditMixin(MapsContextMixin):
     inlines = [OpeningHoursInline, StoreAddressInline]
 
-    def get_form_kwargs(self):
-        kwargs = super(StoreEditMixin, self).get_form_kwargs()
-        kwargs['current_ip'] = get_current_ip(self.request)
-        return kwargs
-
 
 class StoreCreateView(StoreEditMixin, CreateWithInlinesView):
     model = Store
     template_name = "stores/dashboard/store_update.html"
-    form_class = forms.StoreForm
+    form_class = StoreForm
     success_url = reverse_lazy('stores-dashboard:store-list')
 
     def get_context_data(self, **kwargs):
-        ctx = super(StoreCreateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['title'] = _("Create new store")
         return ctx
 
@@ -93,10 +96,10 @@ class StoreCreateView(StoreEditMixin, CreateWithInlinesView):
         messages.error(
             self.request,
             "Your submitted data was not valid - please correct the below errors")
-        return super(StoreCreateView, self).forms_invalid(form, inlines)
+        return super().forms_invalid(form, inlines)
 
     def forms_valid(self, form, inlines):
-        response = super(StoreCreateView, self).forms_valid(form, inlines)
+        response = super().forms_valid(form, inlines)
 
         msg = render_to_string('stores/dashboard/messages/store_saved.html',
                                {'store': self.object})
@@ -107,11 +110,11 @@ class StoreCreateView(StoreEditMixin, CreateWithInlinesView):
 class StoreUpdateView(StoreEditMixin, UpdateWithInlinesView):
     model = Store
     template_name = "stores/dashboard/store_update.html"
-    form_class = forms.StoreForm
+    form_class = StoreForm
     success_url = reverse_lazy('stores-dashboard:store-list')
 
     def get_context_data(self, **kwargs):
-        ctx = super(StoreUpdateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['title'] = self.object.name
         return ctx
 
@@ -119,13 +122,13 @@ class StoreUpdateView(StoreEditMixin, UpdateWithInlinesView):
         messages.error(
             self.request,
             "Your submitted data was not valid - please correct the below errors")
-        return super(StoreUpdateView, self).forms_invalid(form, inlines)
+        return super().forms_invalid(form, inlines)
 
     def forms_valid(self, form, inlines):
         msg = render_to_string('stores/dashboard/messages/store_saved.html',
                                {'store': self.object})
         messages.success(self.request, msg, extra_tags='safe')
-        return super(StoreUpdateView, self).forms_valid(form, inlines)
+        return super().forms_valid(form, inlines)
 
 
 class StoreDeleteView(generic.DeleteView):
@@ -137,7 +140,7 @@ class StoreDeleteView(generic.DeleteView):
         self.object = self.get_object()
         for time in self.object.opening_periods.all():
             time.delete()
-        return super(StoreDeleteView, self).delete(request, *args, **kwargs)
+        return super().delete(request, *args, **kwargs)
 
 
 class StoreGroupListView(generic.ListView):
@@ -148,32 +151,34 @@ class StoreGroupListView(generic.ListView):
 
 class StoreGroupCreateView(generic.CreateView):
     model = StoreGroup
+    fields = ['name', 'slug']
     template_name = "stores/dashboard/store_group_update.html"
     success_url = reverse_lazy('stores-dashboard:store-group-list')
 
     def get_context_data(self, **kwargs):
-        ctx = super(StoreGroupCreateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['title'] = _("Create new store group")
         return ctx
 
     def form_valid(self, form):
-        response = super(StoreGroupCreateView, self).form_valid(form)
+        response = super().form_valid(form)
         messages.success(self.request, _("Store group created"))
         return response
 
 
 class StoreGroupUpdateView(generic.UpdateView):
     model = StoreGroup
+    fields = ['name', 'slug']
     template_name = "stores/dashboard/store_group_update.html"
     success_url = reverse_lazy('stores-dashboard:store-group-list')
 
     def get_context_data(self, **kwargs):
-        ctx = super(StoreGroupUpdateView, self).get_context_data(**kwargs)
+        ctx = super().get_context_data(**kwargs)
         ctx['title'] = self.object.name
         return ctx
 
     def form_valid(self, form):
-        response = super(StoreGroupUpdateView, self).form_valid(form)
+        response = super().form_valid(form)
         messages.success(self.request, _("Store group updated"))
         return response
 
@@ -184,6 +189,6 @@ class StoreGroupDeleteView(generic.DeleteView):
     success_url = reverse_lazy('stores-dashboard:store-group-list')
 
     def form_valid(self, form):
-        response = super(StoreGroupDeleteView, self).form_valid(form)
+        response = super().form_valid(form)
         messages.success(self.request, _("Store group deleted"))
         return response
